@@ -10,15 +10,22 @@ from vertica_python.vertica.connection import Connection
 # Main module for this library.
 
 # The version number of this library.
-VERSION = 0.1.5
+version_info = (0, 1, 7)
+__version__ = '.'.join(map(str, version_info))
+
+__author__ = 'Uber Technologies, Inc'
+__copyright__ = 'Copyright 2013, Uber Technologies, Inc.'
+__license__ = 'MIT'
 
 # The protocol version (3.0.0) implemented in this library.
 PROTOCOL_VERSION = 3 << 16
 
+
 # Opens a new connection to a Vertica database.
 def connect(options):
     return Connection(options)
 
+
 # Properly quotes a value for safe usage in SQL queries.
 #
 # This method has quoting rules for common types. Any other object will be converted to
@@ -36,7 +43,7 @@ def quote(value):
     elif isinstance(value, date):
         return value.strftime("'%Y-%m-%d'::date")
     elif isinstance(value, basestring) or isinstance(value, unicode):
-        return "'{}'".format(re.sub(r"'", "''", value))
+        return "'{0}'".format(re.sub(r"'", "''", value))
     elif isinstance(value, Decimal) or isinstance(value, int) or isinstance(value, long) or isinstance(value, float):
         return str(value)
     elif isinstance(value, list):
@@ -44,6 +51,7 @@ def quote(value):
     else:
         return quote(unicode(value))
 
+
 # Quotes an identifier for safe use within SQL queries, using double quotes.
 def quote_identifier(identifier):
-    return "\"{}\"".format(re.sub(r'\"', '""', unicode(identifier)))
+    return "\"{0}\"".format(re.sub(r'\"', '""', unicode(identifier)))
